@@ -208,6 +208,46 @@ class AnyString(Schema):
 
 
 
+class AnyNonemptyString(AnyString):
+  """
+  <Purpose>
+    Matches any string with one or more characters.
+    This schema can be viewed as the Any() schema applied to Strings, but an
+    additional check is performed to ensure only strings are considered and
+    that said strings have at least one character.
+
+    Supported methods include:
+      matches(): returns a Boolean result.
+      check_match(): raises 'exceptions.FormatError' on a mismatch.
+
+  <Example Use>
+
+    >>> schema = AnyNonemptyString()
+    >>> schema.matches('')
+    False
+    >>> schema.matches('a string')
+    True
+    >>> schema.matches(['a'])
+    False
+    >>> schema.matches(3)
+    False
+    >>> schema.matches(u'a unicode string')
+    True
+    >>> schema.matches({})
+    False
+  """
+
+  def check_match(self, object):
+    AnyString.check_match(self, object)
+
+    if object == "":
+        raise securesystemslib.exceptions.FormatError('Expected a string'
+            ' with at least one character but got ' + repr(object))
+
+
+
+
+
 class AnyBytes(Schema):
   """
   <Purpose>
